#
# spec file for package python-pytest-relaxed
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-relaxed
Version:        2.0.2
Release:        1.3
Summary:        Relaxed test discovery/organization for pytest
License:        BSD-2-Clause
URL:            https://github.com/bitprophet/pytest-relaxed
Source:         https://files.pythonhosted.org/packages/source/p/pytest-relaxed/pytest-relaxed-%{version}.tar.gz
BuildRequires:  %{python_module decorator >= 4}
BuildRequires:  %{python_module pytest >= 7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-decorator >= 4
Requires:       python-pytest >= 7
BuildArch:      noarch
%python_subpackages

%description
Relaxed test discovery/organization plugin for pytest from python-paramiko author

%prep
%autosetup -p1 -n pytest-relaxed-%{version}

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/pytest_relaxed
%{python_sitelib}/pytest_relaxed-%{version}*-info

%changelog
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * :bug:`32` Fix dangling compatibility issues with pytest
    version 8.x. Thanks to Alex Gaynor for the patch!
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Don't try loading Pytest fixture functions as if
    they were test functions. Classifying this as a bug even
    though it's a moderately sized change in behavior;
    it's vanishingly unlikely anybody was relying on this
    somehow!
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Jan 11 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.0:
  * Prior to version 2, we failed to correctly support true Pytest
    setup/teardown methods (i.e. setup_method and teardown_method) and
    these would not get copied to inner class scopes. This has been fixed.
    We still support old nose-style setup/teardown for now, despite them
    going away in Pytest 8.
  * Modernize codebase/project a bunch:
    + Dropped support for Python <3.6 (including 2.7)
    + Pytest support upgraded to support, and require, Pytest >=7.
    + Behavioral changes in Pytest internals have fixed a handful of
    sorta-bugs present in pytest-relaxed under Pytest versions 3 and 4.
- Dropped patches pytest-6.1-and-7.patch, pytest-relaxed-pr10.patch:
  * No longer required.
- Removed six from BuildRequires, is no longer used.
* Tue Apr 12 2022 Ben Greiner <code@bnavigator.de>
- Enhance no-makeitem-method.patch to pytest-6.1-and-7.patch
  gh#bitprophet/pytest-relaxed#21
* Thu Mar 10 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch no-makeitem-method.patch:
  * Support pytest > 6.1
- No longer skip python310.
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Skip python310 -- gh#bitprophet/pytest-relaxed#12
* Wed Nov 17 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add missing BuildRequires on six.
* Tue Oct 13 2020 Benjamin Greiner <code@bnavigator.de>
- Upper limit pytest 6.1 -- gh#bitprophet/pytest-relaxed#12
* Fri May 15 2020 Benjamin Greiner <code@bnavigator.de>
- fix test failure by pytest-relaxed-pr10.patch
  gh#bitprophet/pytest-relaxed#10
* Wed Jan 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip test test_tests_are_colorized_by_test_result as pytest 5.3
  tweaked color output a bit
* Mon Jun 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.5:
  * Fix compatibility with pytest versions 3.3 and above.
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.4:
  * Various tiny fixes in formating/metadata/etc.
- Drop patch python3_fix.patch
* Wed Nov 15 2017 mimi.vx@gmail.com
- initial commit
  * added python3_fix.patch - nonascii characters in README
